import { CssBaseline, ThemeProvider, createTheme, CircularProgress, Box } from '@mui/material'
import { useDeviceType } from './hooks/useDeviceType'
import { useTaskData } from './hooks/useTaskData'
import { DesktopLayout } from './layouts/DesktopLayout'
import { MobileLayout } from './layouts/MobileLayout'
import { StepDetails } from './components/StepDetails'
import type { GroupWithTasks, TaskWithSteps, StepWithNotes } from './types'

const theme = createTheme()

export function App() {
  const deviceType = useDeviceType()
  const {
    groups,
    step,
    loading,
    selectedGroup,
    selectedTask,
    selectedStep,
    setSelectedGroup,
    setSelectedTask,
    setSelectedStep,
    handlePrintStep,
    handlePrintTask,
    handleAddNote,
  } = useTaskData()

  const handleBack = () => {
    if (selectedStep) {
      setSelectedStep(undefined)
    } else if (selectedTask) {
      setSelectedTask(undefined)
    } else if (selectedGroup) {
      setSelectedGroup(undefined)
    }
  }

  if (loading) {
    return (
      <Box sx={{ display: 'flex', justifyContent: 'center', alignItems: 'center', height: '100vh' }}>
        <CircularProgress />
      </Box>
    )
  }

  return (
    <ThemeProvider theme={theme}>
      <CssBaseline />
      {deviceType === 'desktop' ? (
        <DesktopLayout
          groups={groups}
          selectedGroup={selectedGroup}
          selectedTask={selectedTask}
          selectedStep={selectedStep}
          onGroupSelect={setSelectedGroup}
          onTaskSelect={setSelectedTask}
          onStepSelect={setSelectedStep}
          onPrintTask={handlePrintTask}
          onPrintStep={handlePrintStep}
          onAddNote={handleAddNote}
        />
      ) : (
        <>
          {selectedStep ? (
            <StepDetails
              step={step!}
              onPrint={() => handlePrintStep(String(selectedStep.id), '1')} // TODO: Get real user ID
              onAddNote={(content) => handleAddNote(content, '1')} // TODO: Get real user ID
              onBack={handleBack}
            />
          ) : (
            <MobileLayout
              groups={groups}
              selectedGroup={selectedGroup}
              selectedTask={selectedTask}
              selectedStep={selectedStep}
              onGroupSelect={setSelectedGroup}
              onTaskSelect={setSelectedTask}
              onStepSelect={setSelectedStep}
              onBack={handleBack}
            />
          )}
        </>
      )}
    </ThemeProvider>
  )
}
